package de.opalpiraten.scenepainter.gui;
import java.awt.*;
import java.io.*;
import javax.swing.*;
import java.awt.event.*;
import javax.swing.event.*;
import java.beans.*;
import java.net.*;
import de.opalpiraten.scenepainter.sys.*;
import de.opalpiraten.scenepainter.gui.render.*;

/**
 * Frontendclass for combining all the different SceneElementEditors
 * in one window via JTabbedPane
 */
public class SceneElementEditor extends JInternalFrame implements 
ChangeListener, SceneListener, WorkspaceListener {

  /**
   * Container of all the editors
   */
  private JTabbedPane editors = new JTabbedPane();
  
  /**
   * Target of the editing is the selected layer
   */
  private JRadioButton current = new JRadioButton(Dict.get("gui.sceneelementeditor.current"));
  
  /**
   * The User wants the editor to keep track of the scene. If an element
   * gets selected, edit it
   */
  private JCheckBox track = new JCheckBox(Dict.get("gui.sceneelementeditor.track"));
  
  /**
   * Target of the editing is a new layer
   */
  private JRadioButton create = new JRadioButton(Dict.get("gui.sceneelementeditor.create"));
  
  /**
   * The component for editing picturesceneelements
   */
  private PictureSceneElementEditor picturesee;
  
  /**
   * The component for editing TileSceneElements
   */
  private TileSceneElementEditor tilesee;
  
  /**
   * The component for editing TextSceneElements
   */
  private TextSceneElementEditor textsee;
  
  /**
   * The component for editing ComponentSceneElements
   */
  private ComponentSceneElementEditor componentsee;
  
  /**
   * Reference to the scene showing
   */
  private Scene scene;
  
  
  public SceneElementEditor() {
    super(Dict.get("gui.sceneelementeditor.title",""),false,false,false,true);
    
    picturesee = new PictureSceneElementEditor(this);
    tilesee = new TileSceneElementEditor(this);
    textsee = new TextSceneElementEditor(this);
    componentsee = new ComponentSceneElementEditor(this);
    
    editors.add(Dict.get("gui.sceneelementeditor.tab.component"),componentsee);
    editors.add(Dict.get("gui.sceneelementeditor.tab.tile"),tilesee);
    editors.add(Dict.get("gui.sceneelementeditor.tab.picture"),picturesee);
    editors.add(Dict.get("gui.sceneelementeditor.tab.text"),textsee);
    
    ButtonGroup bg = new ButtonGroup();
    bg.add(current);
    bg.add(create);
    create.setSelected(true);
    JPanel content = new JPanel();
    content.setLayout(new BoxLayout(content,BoxLayout.Y_AXIS));

    content.add(editors);
    editors.addChangeListener(this);
    
    JPanel sub = new JPanel();
    sub.add(current);
    sub.add(create);
    content.add(sub);
    setContentPane(content);
    pack();
  }
  
  
  public void replaceProject(Project p) {
    picturesee.replaceProject(p);
    tilesee.replaceProject(p);
    componentsee.replaceProject(p);
  }
  
  public void replaceScene(Scene s) {
    if (scene!=null) scene.removeSceneListener(this);
    scene =s;
    scene.addSceneListener(this);
    tilesee.replaceScene(s);
    componentsee.replaceScene(s);
    textsee.replaceScene(s);
    picturesee.replaceScene(s);
  }
  
  // Interface implemententation
  public void sceneChanged(Scene s) {
    SceneElement e = s.getSelected();
    if (e==null) return;
    if (e instanceof TileSceneElement) editors.setSelectedComponent(tilesee);
    if (e instanceof PictureSceneElement) editors.setSelectedComponent(picturesee);
    if (e instanceof ComponentSceneElement) {
      editors.setSelectedComponent(componentsee);
      create.setSelected(false);
      current.setSelected(true);
    }
    if (e instanceof TextSceneElement) {
      editors.setSelectedComponent(textsee); 
      create.setSelected(false);
      current.setSelected(true);
    }
  }
  
  /**
   * Query if the editing target is the current or a new layer
   * @return true if a new layer is to be added
   */
  public boolean isCreating() {
    return create.isSelected();
  }
  
  public void stateChanged(ChangeEvent e) {
    create.setSelected(true);
  }

}